# CustomObjectBulkDeleteFilterConditionOperator


## Enum

* `EQ` (value: `'EQ'`)

* `GT` (value: `'GT'`)

* `LT` (value: `'LT'`)

* `GE` (value: `'GE'`)

* `LE` (value: `'LE'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


